@@ -79,8 +79,6 @@ class AdbExt(object):
             arg = 'exec-out screencap -p'.format(self.util.sn)
             out = self.util.adb(arg, encoding=None)  # 这里是 png bytes string
 
-        print(type(out), 'tango')
-
         # 保存截图
         if pc_path:
             if self.util.is_py2:
@@ -209,7 +207,7 @@ class AdbExt(object):
             arg = arg + ' -g'
         if with_r:
             arg = arg + ' -r'
-        self.util.adb('{} "{}"'.format(arg, apk_path))
+        self.util.adb('{} "{}"'.format(arg, apk_path), timeout=60 * 5)  # 安装较大的包可能比较耗时
 
     def uninstall(self, pkg):
         """
